#!/bin/sh

# Abort on error.
set -e

# debian/rules will replace this with the package name.
DOCLNK=/usr/share/doc/PKGNAME
if test "$1" = upgrade \
    -a -L $DOCLNK \
    && dpkg --compare-versions "$2" lt-nl 5.0-13
then
    rm $DOCLNK
fi

# dh_installdeb will replace this with shell code automatically
# generated by other debhelper scripts.

#DEBHELPER#

exit 0
